%global _hardened_build 1

## NOTE: Lots of files in various subdirectories have the same name (such as
## "LICENSE") so this short macro allows us to distinguish them by using their
## directory names (from the source tree) as prefixes for the files.
%global add_to_license_files() \
        mkdir -p _license_files ; \
        cp -p %1 _license_files/$(echo '%1' | sed -e 's!/!.!g')

%define prerel alpha4
%define prerel_tag -%{prerel}
%define date 20190626

%define build_docs 0

%define rel 1.%{prerel}.4

%define qtmajor 5
%define qtminor 15
%define qtsubminor 0

%define major_private 1
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define libqt5webkitwidgets %mklibname qt5webkitwidgets %qtmajor
%define libqt5webkitwidgets_d %mklibname qt%{qtmajor}webkitwidgets -d

%define libqt5webkit %mklibname qt5webkit %qtmajor
%define libqt5webkit_d %mklibname qt%{qtmajor}webkit -d

%define qttarballdir qtwebkit-%version%{?prerel_tag}

# Reduce build parallelism on machines with low memory
# make -j8 fails on a machine with 8G RAM + 4G swap
%global _smp_ncpus_max $(expr $(free -g -t | awk '/Total:/{print $2}') / 2)

Name:           qtwebkit5
Version:        5.212.0
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} WebKit component
Group:          System/Libraries
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://github.com/qtwebkit/qtwebkit
Source0:        https://github.com/qtwebkit/qtwebkit/releases/download/%{qttarballdir}/%{qttarballdir}.tar.xz
Patch0:		   qtwebkit-5.212.0-alpha4-icu-true.patch
Patch2:         qtwebkit-5.212.0_cmake_cmp0071.patch
Patch3:         qtwebkit-5.212.0-json.patch
Patch4:         qtwebkit-bison37.patch
Patch5:         0001-Remove-invalid-g_object-declarations-to-fix-build-with-glib-2.68.patch
## upstream patches

Source1:        pthread.patch
# tweak linker flags to minimize memory usage on "small" platforms
Source2:        qtwebkit-opensource-src-5.2.0-save_memory.patch

BuildRequires:  qtbase5-devel
BuildRequires:  hyphen-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gperf
BuildRequires:  chrpath
BuildRequires:  python
BuildRequires:  ruby-devel
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(libwoff2dec)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  cmake
BuildRequires:  findutils
BuildRequires:  pngcrush

# We're supposed to specify versions here, but these crap Google libs don't do
# normal releases. Accordingly, they're not suitable to be system libs.
Provides:       bundled(angle)
Provides:       bundled(brotli)
Provides:       bundled(woff2)

#Branch Patchs

#Trunk Patchs

#Patch from Mageia


%description
Qt%{qtmajor} WebKit library is an open source web browser engine.

%files
%{_qt5_libexecdir}/QtWebPluginProcess
%{_qt5_libexecdir}/QtWebProcess
%{_qt5_libexecdir}/QtWebNetworkProcess
%{_qt5_libexecdir}/QtWebStorageProcess
%{_qt5_qml}/QtWebKit

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary: QtWebKit%{qtmajor} APIs and tools docs
Group:   Documentation
BuildArch: noarch
BuildRequires: qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires: qttools5-assistant
Recommends: qttools5-assistant

%description doc
Documentation for APIs and tools in QtWebKit5 package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtwebkit.qch
%{_qt5_docdir}/qtwebkit/
%endif

#------------------------------------------------------------------------------

%package -n %{libqt5webkitwidgets}
Summary: Qt%{qtmajor} Lib
Group: System/Libraries

%description -n %{libqt5webkitwidgets}
Qt%{qtmajor} Lib.

%files -n %{libqt5webkitwidgets}
%{_qt5_libdir}/libQt5WebKitWidgets.so.%{qtmajor}*

#------------------------------------------------------------------------------

%package -n %{libqt5webkitwidgets_d}
Summary: Devel files needed to build apps based on QtWebKitWidgets
Group:    Development/Libraries
Requires: %{libqt5webkitwidgets} = %version
Requires: qtbase5-common-devel 
Provides: libqt5webkitwidgets-devel = %version
Provides: qt5webkitwidgets-devel = %version
Provides: libqtwebkitwidgets5-devel = %version
Provides: qtwebkitwidgets5-devel = %version

Provides: libqt5webkitwidgets-private-devel = %version
Provides: qt5webkitwidgets-private-devel = %version
Provides: libqtwebkitwidgets5-private-devel = %version
Provides: qtwebkitwidgets5-private-devel = %version

%description -n %{libqt5webkitwidgets_d}
Devel files needed to build apps based on QtWebKitWidgets.

%files -n %{libqt5webkitwidgets_d}
%{_qt5_libdir}/libQt5WebKitWidgets.so
%{_qt5_libdir}/pkgconfig/Qt5WebKitWidgets.pc
%{_qt5_includedir}/QtWebKitWidgets
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webkitwidgets.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webkitwidgets_private.pri
%{_qt5_libdir}/cmake/Qt5WebKitWidgets

#------------------------------------------------------------------------------

%package -n %{libqt5webkit}
Summary: Qt%{qtmajor} Lib
Group: System/Libraries

%description -n %{libqt5webkit}
Qt%{qtmajor} Lib.

%files -n %{libqt5webkit}
%{_qt5_libdir}/libQt5WebKit.so.%{qtmajor}*

#------------------------------------------------------------------------------

%package -n %{libqt5webkit_d}
Summary: Devel files needed to build apps based on QtWebKit
Group:    Development/Libraries
Requires: %{libqt5webkit} = %version
Provides: libqt5webkit-devel = %version
Provides: qt5webkit-devel = %version
Provides: libqtwebkit5-devel = %version
Provides: qtwebkit5-devel = %version

Provides: libqt5webkit-private-devel = %version
Provides: qt5webkit-private-devel = %version
Provides: libqtwebkit5-private-devel = %version
Provides: qtwebkit5-private-devel = %version

%description -n %{libqt5webkit_d}
Devel files needed to build apps based on QtWebKit.

%files -n %{libqt5webkit_d}
%{_qt5_libdir}/libQt5WebKit.so
%{_qt5_libdir}/pkgconfig/Qt5WebKit.pc
%{_qt5_includedir}/QtWebKit
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webkit.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webkit_private.pri
%{_qt5_libdir}/cmake/Qt5WebKit

#------------------------------------------------------------------------------

%prep
%setup -q -n %qttarballdir
%apply_patches

# find/fix pngs with "libpng warning: iCCP: known incorrect sRGB profile"
find -name \*.png | xargs -n1 pngcrush -ow -fix

%build
# The following changes of optflags ietc. are adapted from webkitgtk4 package, which
# is mostly similar to this one...
#
# Increase the DIE limit so our debuginfo packages could be size optimized.
# Decreases the size for x86_64 from ~5G to ~1.1G.
# https://bugzilla.redhat.com/show_bug.cgi?id=1456261
%define _dwz_max_die_limit 250000000

# Decrease debuginfo even on ix86 because of:
# https://bugs.webkit.org/show_bug.cgi?id=140176
%ifarch s390 s390x %{arm} %{ix86} ppc %{power64} %{mips} aarch64
# Decrease debuginfo verbosity to reduce memory consumption even more
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

%ifarch ppc
# Use linker flag -relax to get WebKit build under ppc(32) with JIT disabled
%global optflags %{optflags} -Wl,-relax
%endif

CFLAGS="${CFLAGS:-%optflags}" ; export CFLAGS ;
CXXFLAGS="${CXXFLAGS:-%optflags} -fpermissive -Wno-class-memaccess" ; export CXXFLAGS ;
# We cannot use default cmake macro here as it overwrites some settings queried
# by qtwebkit cmake from qmake
cmake  . \
       -DPORT=Qt \
       -DCMAKE_BUILD_TYPE=Release \
       -DENABLE_TOOLS=OFF \
       -DCMAKE_C_FLAGS_RELEASE:STRING="-DNDEBUG" \
       -DCMAKE_CXX_FLAGS_RELEASE:STRING="-DNDEBUG" \
       -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON \
%ifarch s390 s390x ppc %{power64}
       -DENABLE_JIT=OFF \
%endif
%ifarch s390 s390x ppc %{power64}
       -DUSE_SYSTEM_MALLOC=ON \
%endif
%if 0%{?docs}
       -DGENERATE_DOCUMENTATION=ON \
%endif
       .

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# .la and .a files, die, die, die.
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# fix pkgconfig files
#sed -i '/Name/a Description: Qt5 WebKit module' %%{buildroot}%%{_libdir}/pkgconfig/Qt5WebKit.pc
#sed -i "s,Cflags: -I%%{_qt5_includedir}/Qt5WebKit,Cflags: -I%%{_qt5_includedir}/QtWebKit,g" %%{buildroot}%%{_libdir}/pkgconfig/Qt5WebKit.pc
# strictly speaking, this isn't *wrong*, but can made more readable, so let's do that
sed -i "s,Libs: -L%{_qt5_libdir}/qt5/../ -lQt5WebKit,Libs: -L%{_qt5_libdir} -lQt5WebKit ,g" %{buildroot}%{_libdir}/pkgconfig/Qt5WebKit.pc

#sed -i '/Name/a Description: Qt5 WebKitWidgets module' %%{buildroot}%%{_libdir}/pkgconfig/Qt5WebKitWidgets.pc
#sed -i "s,Cflags: -I%%{_qt5_includedir}/Qt5WebKitWidgets,Cflags: -I%%{_qt5_includedir}/QtWebKitWidgets,g" %%{buildroot}%%{_libdir}/pkgconfig/Qt5WebKitWidgets.pc
sed -i "s,Libs: -L%{_qt5_libdir}/qt5/../ -lQt5WebKitWidgets,Libs: -L%{_qt5_libdir} -lQt5WebKitWidgets ,g" %{buildroot}%{_libdir}/pkgconfig/Qt5WebKitWidgets.pc

# Finally, copy over and rename various files for %%license inclusion
%add_to_license_files Source/JavaScriptCore/COPYING.LIB
%add_to_license_files Source/JavaScriptCore/icu/LICENSE
%add_to_license_files Source/ThirdParty/ANGLE/LICENSE
%add_to_license_files Source/ThirdParty/ANGLE/src/third_party/compiler/LICENSE
%add_to_license_files Source/ThirdParty/ANGLE/src/third_party/murmurhash/LICENSE
%add_to_license_files Source/WebCore/icu/LICENSE
%add_to_license_files Source/WebCore/LICENSE-APPLE
%add_to_license_files Source/WebCore/LICENSE-LGPL-2
%add_to_license_files Source/WebCore/LICENSE-LGPL-2.1
%add_to_license_files Source/WebInspectorUI/UserInterface/External/CodeMirror/LICENSE
%add_to_license_files Source/WebInspectorUI/UserInterface/External/Esprima/LICENSE
%add_to_license_files Source/WTF/icu/LICENSE
%add_to_license_files Source/WTF/wtf/dtoa/COPYING
%add_to_license_files Source/WTF/wtf/dtoa/LICENSE

%check
# verify Qt5WebKit cflags non-use of -I/.../Qt5WebKit
export PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig
test -z "$(pkg-config --cflags Qt5WebKit | grep Qt5WebKit)"


%changelog
* Tue Sep 13 2022 tex - 5.122.0-1.alpha4.4pclos2022
- rebuild for new icu

* Sat Sep 18 2021 tex - 5.122.0-1.alpha4.3pclos2021
- rebuild for new icu

* Fri Nov 20 2020 tex - 5.122.0-1.alpha4.2pclos2020
- rebuild
